depends = ('ITKPyBase', 'ITKImageFunction', )
templates = (
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('PadImageFilterBase', 'itk::PadImageFilterBase', 'itkPadImageFilterBaseICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('PadImageFilter', 'itk::PadImageFilter', 'itkPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BSplineDownsampleImageFilter', 'itk::BSplineDownsampleImageFilter', 'itkBSplineDownsampleImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BSplineUpsampleImageFilter', 'itk::BSplineUpsampleImageFilter', 'itkBSplineUpsampleImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('BinShrinkImageFilter', 'itk::BinShrinkImageFilter', 'itkBinShrinkImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('ChangeInformationImageFilter', 'itk::ChangeInformationImageFilter', 'itkChangeInformationImageFilterIF3', True, 'itk::Image< float,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('ConstantPadImageFilter', 'itk::ConstantPadImageFilter', 'itkConstantPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('CropImageFilter', 'itk::CropImageFilter', 'itkCropImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('CyclicShiftImageFilter', 'itk::CyclicShiftImageFilter', 'itkCyclicShiftImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ExpandImageFilter', 'itk::ExpandImageFilter', 'itkExpandImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('FlipImageFilter', 'itk::FlipImageFilter', 'itkFlipImageFilterIF3', True, 'itk::Image< float,3 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('InterpolateImageFilter', 'itk::InterpolateImageFilter', 'itkInterpolateImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('MirrorPadImageFilter', 'itk::MirrorPadImageFilter', 'itkMirrorPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('OrientImageFilter', 'itk::OrientImageFilter', 'itkOrientImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('PasteImageFilter', 'itk::PasteImageFilter', 'itkPasteImageFilterIF3', True, 'itk::Image< float,3 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterISS3', True, 'itk::Image< signed short,3 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('PermuteAxesImageFilter', 'itk::PermuteAxesImageFilter', 'itkPermuteAxesImageFilterIF3', True, 'itk::Image< float,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVISS2VISS2', True, 'itk::VectorImage< signed short,2 >, itk::VectorImage< signed short,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVIUC2VIUC2', True, 'itk::VectorImage< unsigned char,2 >, itk::VectorImage< unsigned char,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVIUS2VIUS2', True, 'itk::VectorImage< unsigned short,2 >, itk::VectorImage< unsigned short,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVIF2VIF2', True, 'itk::VectorImage< float,2 >, itk::VectorImage< float,2 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVISS3VISS3', True, 'itk::VectorImage< signed short,3 >, itk::VectorImage< signed short,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVIUC3VIUC3', True, 'itk::VectorImage< unsigned char,3 >, itk::VectorImage< unsigned char,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVIUS3VIUS3', True, 'itk::VectorImage< unsigned short,3 >, itk::VectorImage< unsigned short,3 >'),
  ('RegionOfInterestImageFilter', 'itk::RegionOfInterestImageFilter', 'itkRegionOfInterestImageFilterVIF3VIF3', True, 'itk::VectorImage< float,3 >, itk::VectorImage< float,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVIUC2VIUC2', True, 'itk::VectorImage< unsigned char,2 >,itk::VectorImage< unsigned char,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVISS2VISS2', True, 'itk::VectorImage< signed short,2 >,itk::VectorImage< signed short,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVIUS2VIUS2', True, 'itk::VectorImage< unsigned short,2 >,itk::VectorImage< unsigned short,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVIF2VIF2', True, 'itk::VectorImage< float,2 >,itk::VectorImage< float,2 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVIUC3VIUC3', True, 'itk::VectorImage< unsigned char,3 >,itk::VectorImage< unsigned char,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVISS3VISS3', True, 'itk::VectorImage< signed short,3 >,itk::VectorImage< signed short,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVIUS3VIUS3', True, 'itk::VectorImage< unsigned short,3 >,itk::VectorImage< unsigned short,3 >'),
  ('ResampleImageFilter', 'itk::ResampleImageFilter', 'itkResampleImageFilterVIF3VIF3', True, 'itk::VectorImage< float,3 >,itk::VectorImage< float,3 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ShrinkImageFilter', 'itk::ShrinkImageFilter', 'itkShrinkImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('SliceBySliceImageFilter', 'itk::SliceBySliceImageFilter', 'itkSliceBySliceImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('SliceBySliceImageFilter', 'itk::SliceBySliceImageFilter', 'itkSliceBySliceImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('SliceBySliceImageFilter', 'itk::SliceBySliceImageFilter', 'itkSliceBySliceImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('SliceBySliceImageFilter', 'itk::SliceBySliceImageFilter', 'itkSliceBySliceImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('SliceBySliceImageFilter', 'itk::SliceBySliceImageFilter', 'itkSliceBySliceImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('SliceBySliceImageFilter', 'itk::SliceBySliceImageFilter', 'itkSliceBySliceImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterISS2ISS3', True, 'itk::Image< signed short,2 >,itk::Image< signed short,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUC2IUC3', True, 'itk::Image< unsigned char,2 >,itk::Image< unsigned char,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIUS2IUS3', True, 'itk::Image< unsigned short,2 >,itk::Image< unsigned short,3 >'),
  ('TileImageFilter', 'itk::TileImageFilter', 'itkTileImageFilterIF2IF3', True, 'itk::Image< float,2 >,itk::Image< float,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS2ISS2IVF22', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS3ISS3IVF23', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS2ISS2IVF32', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS3ISS3IVF33', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS2ISS2IVF42', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterISS3ISS3IVF43', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUC2IUC2IVF22', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUC3IUC3IVF23', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUC2IUC2IVF32', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUC3IUC3IVF33', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUC2IUC2IVF42', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUC3IUC3IVF43', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUS2IUS2IVF22', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUS3IUS3IVF23', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUS2IUS2IVF32', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUS3IUS3IVF33', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUS2IUS2IVF42', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIUS3IUS3IVF43', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIF2IF2IVF22', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIF3IF3IVF23', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIF2IF2IVF32', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIF3IF3IVF33', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIF2IF2IVF42', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('WarpImageFilter', 'itk::WarpImageFilter', 'itkWarpImageFilterIF3IF3IVF43', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('WrapPadImageFilter', 'itk::WrapPadImageFilter', 'itkWrapPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIRGBUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIRGBUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIRGBAUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIRGBAUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('ZeroFluxNeumannPadImageFilter', 'itk::ZeroFluxNeumannPadImageFilter', 'itkZeroFluxNeumannPadImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
)
snake_case_functions = ('permute_axes_image_filter', 'warp_image_filter', 'interpolate_image_filter', 'flip_image_filter', 'shrink_image_filter', 'orient_image_filter', 'b_spline_upsample_image_filter', 'wrap_pad_image_filter', 'zero_flux_neumann_pad_image_filter', 'paste_image_filter', 'resample_image_filter', 'mirror_pad_image_filter', 'b_spline_resample_image_filter_base', 'slice_by_slice_image_filter', 'pad_image_filter', 'cyclic_shift_image_filter', 'region_of_interest_image_filter', 'b_spline_downsample_image_filter', 'tile_image_filter', 'bin_shrink_image_filter', 'change_information_image_filter', 'constant_pad_image_filter', 'crop_image_filter', 'expand_image_filter', 'pad_image_filter_base', )
